@@ -1,7 +1,10 @@
 from .tool import Tool
 from .bowtie2 import Bowtie2
+from .cellranger import CellRangerMkfastq
 from .cutadapt import Cutadapt
 from .kraken2 import Kraken2
+from .shi7 import Shi7
+from .shogun import ShogunAlign, ShogunFilter
 from .star import STARInstance
 from .test import Test
 from .unicycler import Unicycler
