@@ -4,8 +4,10 @@ toolchest_client.tools.kraken2
 
 This is the Kraken2 implementation of the Tool class.
 """
+import os
+
 from . import Tool
-from toolchest_client.files import concatenate_files
+from toolchest_client.files import OutputType, assert_exists
 
 
 class Kraken2(Tool):
@@ -25,8 +27,14 @@ class Kraken2(Tool):
             max_inputs=2,
             database_name=database_name,
             database_version=database_version,
-            parallel_enabled=True,
+            parallel_enabled=False,
+            output_type=OutputType.GZ_TAR,
+            output_is_directory=True,
         )
 
-    def _merge_outputs(self, output_file_paths):
-        concatenate_files(output_file_paths, self.output_path)
+    def _sanity_output_check(self):
+        for output_name in ["kraken2_output.txt", "kraken2_report.txt"]:
+            output_file_path = f"{self.output_path}/{output_name}"
+            assert_exists(output_file_path, must_be_file=True)
+            if os.stat(output_file_path).st_size <= 100:
+                raise ValueError(f"Kraken 2 output file at {output_file_path} is suspiciously small")
